Stocky
===============

Stocky is a program that lets you track stocks, their performance, and other financial information... all at your fingertips and through your closest terminal emulator. Powered by python.

Work in Progress!
=================
